@@ -4,7 +4,7 @@ use warnings;
 no warnings qw(redefine);
 package RT::Extension::BooleanCustomField;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =encoding utf8
 
@@ -78,7 +78,7 @@ $RT::CustomField::FieldTypes{Boolean} = {
 
 =head1 AUTHOR
 
-Gérald Sédrati-Dinet E<lt>gibus@easter-eggs.comE<gt>
+Gérald Sédrati E<lt>gibus@easter-eggs.comE<gt>
 
 =head1 REPOSITORY
 
@@ -96,7 +96,7 @@ L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-Bool
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2018 by Gérald Sédrati-Dinet, Easter-Eggs
+This software is Copyright (c) 2018-2022 by Gérald Sédrati, Easter-Eggs
 
 This is free software, licensed under:
 
